# WorkstreamCreateRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**prefix** | **str** | Must consist of 3 positive whole numbers | 
**name** | **str** | Max length 60 characters | 
**description** | **str** | Max length 500 characters | [optional] 
**contact_name** | **str** | Max length 50 characters | [optional] 
**contact_number** | **str** | Max length 20 characters | [optional] 
**contact_email** | **str** | Max length 320 characters | [optional] 
**emergency_contact_name** | **str** | Max length 100 characters | [optional] 
**emergency_contact_number** | **str** | Max length 100 characters | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

